@@ -129,7 +129,7 @@ def bbox_option(f):
 
 
 def validate_bbox(ctx, param, value):
-    if len(value) < 4:
+    if value is None or len(value) < 4:
         return None
     return format_bbox(*value)
 
